@@ -1,11 +1,14 @@
 import re
+from typing import List
+
 
 class Dictionary:
     """
-    Stores the elements of an Frelatage dictionary. 
+    Stores the elements of an Frelatage dictionary.
     """
+
     def __init__(self) -> None:
-        self.dictionary = []
+        self.dictionary: List[str] = []
         # dict_element="myelement" -> "myelement"
         self.DICTIONARY_ELEMENT_REGEXP = r'".+"'
 
@@ -23,9 +26,11 @@ class Dictionary:
                 if not line or line[0] == "#":
                     continue
                 # Parse line
-                dictionary_element = re.findall(self.DICTIONARY_ELEMENT_REGEXP, line)
+                dictionary_element = re.findall(
+                    self.DICTIONARY_ELEMENT_REGEXP, line
+                )
                 if dictionary_element:
                     # Remove the quote from both the beginning and the end
                     dictionary_element = dictionary_element[0][1:-1]
                     file_dictionary.append(dictionary_element)
-        return file_dictionary
\ No newline at end of file
+        return file_dictionary
